:mod:`nilearn.surface`: Manipulating Surface Data
=================================================

.. automodule:: nilearn.surface
   :no-members:
   :no-inherited-members:

.. No relevant user manual section yet.

Classes
-------

.. currentmodule:: nilearn.surface

.. autosummary::
   :toctree: generated/
   :template: class.rst

    FileMesh
    InMemoryMesh
    PolyData
    PolyMesh
    SurfaceImage
    SurfaceMesh

.. autoclasstree:: nilearn.surface
   :full:

Functions
---------

.. currentmodule:: nilearn.surface

.. autosummary::
   :toctree: generated/
   :template: function.rst

   load_surf_data
   load_surf_mesh
   vol_to_surf
